@@ -26,7 +26,7 @@ ma_select <- function(d, ep, .id){
   if(grepl("^Category:", url)){
     d <- ma_category_pages(ep[1], url, c(".category-page__members", ".category-page__pagination"))
   } else {
-    if(length(ep) > 1) stop(paste0("Invalid enpoint: ", ep[1],
+    if(length(ep) > 1) stop(paste0("Invalid endpoint: ", ep[1],
                                    " is an article but `endpoint` does not terminate here."), call. = FALSE)
     d <- ma_article(url, browse = FALSE)
   }
@@ -40,14 +40,14 @@ ma_select <- memoise::memoise(ma_select)
 # Recursively collate all subcategories or articles for a given category's page(s)
 ma_category_pages <- function(id, url, nodes, d0 = NULL){
   x <- xml2::read_html(ma_base_add(url))
-  x1 <- rvest::html_nodes(x, nodes[1]) %>% rvest::html_nodes("ul a")
+  x1 <- rvest::html_nodes(x, nodes[1]) |> rvest::html_nodes("ul a")
   x1 <- x1[grepl("class=\"category-page__member-link\"", x1)]
-  txt <- ma_text(x1) %>% ma_strip_prefix()
+  txt <- ma_text(x1) |> ma_strip_prefix()
   url <- ma_href(x1)
-  d <- dplyr::tibble(txt, url) %>% stats::setNames(c(id, "url"))
+  d <- dplyr::tibble(txt, url) |> stats::setNames(c(id, "url"))
   if(!is.null(d0)) d <- dplyr::bind_rows(d0, d)
 
-  x <- rvest::html_nodes(x, nodes[2]) %>% rvest::html_nodes("a")
+  x <- rvest::html_nodes(x, nodes[2]) |> rvest::html_nodes("a")
   if(!length(x)) return(d)
   txt <- ma_text(x)
   url <- ma_href(x)
@@ -62,13 +62,14 @@ ma_category_pages <- function(id, url, nodes, d0 = NULL){
 ma_category_pages <- memoise::memoise(ma_category_pages)
 
 ma_portal_technology_cleanup <- function(d){
-  dplyr::mutate(d,
-                group = ifelse(.data[["id"]] == "more", gsub("Category:", "", .data[["url"]]), .data[["group"]]),
-                group = gsub(":$", "", .data[["group"]]),
-                id = ifelse(.data[["id"]] == "more",
-                            paste("Other", tolower(gsub("Category:", "", .data[["url"]]))), .data[["id"]]),
-                id = ifelse(grepl("^-[A-Z]$", .data[["id"]]),
-                            gsub("\\(|\\)", "", gsub("_", " ", .data[["url"]])), .data[["id"]])
+  dplyr::mutate(
+    d,
+    group = ifelse(.data[["id"]] == "more", gsub("Category:", "", .data[["url"]]), .data[["group"]]),
+    group = gsub(":$", "", .data[["group"]]),
+    id = ifelse(.data[["id"]] == "more",
+                paste("Other", tolower(gsub("Category:", "", .data[["url"]]))), .data[["id"]]),
+    id = ifelse(grepl("^-[A-Z]$", .data[["id"]]),
+                gsub("\\(|\\)", "", gsub("_", " ", .data[["url"]])), .data[["id"]])
   )
 }
 
@@ -77,7 +78,7 @@ ma_portal_series_cleanup <- function(d){
 }
 
 ma_article_categories <- function(x){
-  x <- rvest::html_node(x, "#articleCategories") %>% rvest::html_nodes("li span a")
+  x <- rvest::html_node(x, "#articleCategories") |> rvest::html_nodes("li span a")
   x <- x[!grepl(".*Category:Memory_Alpha_pages_with.*", x)]
   url <- ma_href(x)
   x <- ma_text(x)
@@ -88,15 +89,15 @@ ma_article_aside <- function(x){
   x <- rvest::html_children(x)
   idx <- which(rvest::html_name(x)  == "aside")
   if(!length(idx)) return()
-  x <- x[[idx[1]]] %>% rvest::html_children()
+  x <- x[[idx[1]]] |> rvest::html_children()
   img <- .ma_aside_image(x)
-  cols <- rvest::html_nodes(x, ".pi-data-label") %>% ma_text()
+  cols <- rvest::html_nodes(x, ".pi-data-label") |> ma_text()
   cols <- gsub(":$", "", cols)
   cols <- gsub("\\s", "_", cols)
   x <- rvest::html_nodes(x, ".pi-data-value")
   if(length(x) != length(cols)) return()
   vals <- purrr::map(x, ~{
-    x <- xml2::xml_contents(.x) %>% ma_text(trim = FALSE)
+    x <- xml2::xml_contents(.x) |> ma_text(trim = FALSE)
     x[x %in% c("", " ")] <- "|"
     x <- gsub("\\)", "\\)|", x)
     x <- gsub("[|]+$", "", paste0(x, collapse = ""))
@@ -106,7 +107,7 @@ ma_article_aside <- function(x){
     x <- gsub("[ ]+", " ", x)
     x <- gsub("^[|]", "", x)
     trimws(x)
-  }) %>% stats::setNames(cols)
+  }) |> stats::setNames(cols)
   d <- tibble::as_tibble(vals)
   dplyr::mutate(d, Image = img)
 }
@@ -114,7 +115,7 @@ ma_article_aside <- function(x){
 .ma_aside_image <- function(x){
   idx <- which(rvest::html_name(x) == "figure")[1]
   if(!length(idx)) return(as.character(NA))
-  x <- rvest::html_nodes(x[idx], ".image-thumbnail") %>% mb_href()
+  x <- rvest::html_nodes(x[idx], ".image-thumbnail") |> mb_href()
   x <- strsplit(x, "/")[[1]]
   idx <- grep("\\.jpg", x, ignore.case = TRUE)
   if(!length(idx)) return(as.character(NA))
